@@ -3,7 +3,7 @@
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
- * Copyright 2002 Roland Stigge
+ * Copyright 2002, 2003 Roland Stigge
  *
  */
 
@@ -235,7 +235,7 @@ static void cb_info_window(GtkWidget *widget _U_, gpointer data,
 
     { "ISDN device:", strdup(session->isdn_device_name) },
     { "ISDN speed (samples):", ltostr(8000) },
-    { "ISDN sample size (bite):", ltostr(8) },
+    { "ISDN sample size (bits):", ltostr(8) },
     { "ISDN fragment size (bytes):", ltostr(255) }
   };
   unsigned int i;
@@ -308,14 +308,14 @@ static void cb_info_window(GtkWidget *widget _U_, gpointer data,
 static void cb_about(GtkWidget *widget _U_, gpointer data _U_, guint action _U_) {
   GtkWidget *window = ok_dialog_get("About ANT",
 			"ANT (ANT is Not a Telephone) Version " VERSION "\n"
-			"Copyright 2002 Roland Stigge\n\n"
+			"Copyright 2002, 2003 Roland Stigge\n\n"
 			"This is an ISDN telephone application\n"
 			"written for GNU/Linux and ISDN4Linux for\n"
 			"communicating via a full duplex soundcard (or\n"
 			"multiple sound devices if you like) and an\n"
 			"audio capable I4L ISDN device\n\n"
 			"Contact:\n"
-			"Roland Stigge, stigge@epost.de\n"
+			"Roland Stigge, stigge@antcom.de\n"
 			"http://www.antcom.de/"
 				    , GTK_JUSTIFY_CENTER);
 
@@ -326,7 +326,7 @@ static void cb_about(GtkWidget *widget _U_, gpointer data _U_, guint action _U_)
 static void cb_license(GtkWidget *widget _U_, gpointer data _U_, guint action _U_) {
   GtkWidget *window = ok_dialog_get("ANT License",
     "ANT (ANT is Not a Telephone)\n"
-    "Copyright (C) 2002 Roland Stigge\n"
+    "Copyright (C) 2002, 2003 Roland Stigge\n"
     "\n"
     "This program is free software; you can redistribute it and/or\n"
     "modify it under the terms of the GNU General Public License\n"
@@ -603,12 +603,12 @@ int main_gtk(struct session_t *session) {
 		   session->llcheck, FALSE, FALSE, 0);
 
   session->llcheck_in =
-    llcheck_bar_new(66, 10, 200, 0, 0);
+    llcheck_bar_new(66, 10, 0, 200, 0);
   gtk_box_pack_start(GTK_BOX(session->llcheck),
 		   session->llcheck_in, FALSE, FALSE, 0);
   gtk_widget_show(session->llcheck_in);
   session->llcheck_out =
-    llcheck_bar_new(66, 10, 0, 200, 0);
+    llcheck_bar_new(66, 10, 200, 0, 0);
   gtk_box_pack_start(GTK_BOX(session->llcheck),
 		   session->llcheck_out, FALSE, FALSE, 0);
   gtk_widget_show(session->llcheck_out);
@@ -672,7 +672,13 @@ int main_gtk(struct session_t *session) {
   gtk_widget_show(main_window);
 
   settings_history_read(session); /* get history from home dir dotfile */
+  gtk_clist_freeze(GTK_CLIST(session->cid_list));
   settings_callerid_read(session); /* get callerid history */
+  if (session->option_calls_merge)
+    cid_calls_merge(session); /* merge history from isdnlog */
+  gtk_clist_thaw(GTK_CLIST(session->cid_list));
+  cid_jump_to_end(session);
+  cid_jump_to_end(session);
 
   /* connect isdn and sound input handlers to gdk pseudo select */
   session_io_handlers_start(session);
