@@ -3,7 +3,7 @@
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
- * Copyright 2002 Roland Stigge
+ * Copyright 2002, 2003 Roland Stigge
  *
  */
 
@@ -25,6 +25,7 @@
 #include "sound.h"
 #include "gtk.h"
 #include "settings.h"
+#include "recording.h"
 
 /*
  * Load all settings from widgets into session
@@ -43,6 +44,7 @@ static int gtksettings_try(GtkWidget *widget) {
   int successful = 1;
   GtkWidget *entry;
   GtkWidget *button;
+  GSList *list;
 
   /* exec_on_incoming */
   entry = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(widget),
@@ -53,6 +55,28 @@ static int gtksettings_try(GtkWidget *widget) {
   } else
     fprintf(stderr, "gtksettings_cb_ok: Error getting exec_on_incoming.\n");
 
+  /* popup checkbutton */
+  button = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(widget),
+					     "popup_checkbutton");
+  if (button)
+    session->option_popup =
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
+  else
+    fprintf(stderr, "gtksettings_cb_ok: Error getting popup state.\n");
+  
+  /* recording_format */
+  list = (GSList *) gtk_object_get_data(GTK_OBJECT(widget), "recording_format");
+  if (list) {
+    while (list) {
+      if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(list->data))) {
+	session->option_recording_format = (enum recording_format_t)
+	    gtk_object_get_data(GTK_OBJECT(list->data), "rec_format");
+      }
+      list = list->next;
+    }
+  } else
+    fprintf(stderr, "gtksettings_cb_ok: Error getting recording_format.\n");
+
   /* msn */
   entry = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(widget), "msn_entry");
   if (entry)
@@ -87,6 +111,25 @@ static int gtksettings_try(GtkWidget *widget) {
     fprintf(stderr, "gtksettings_cb_ok: "
 	    "Error getting caller id maximum rows.\n");
 
+  /* cid_calls_merge_checkbutton */
+  button = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(widget),
+					     "cid_calls_merge_checkbutton");
+  if (button)
+    session->option_calls_merge =
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
+  else
+    fprintf(stderr,
+	    "gtksettings_cb_ok: Error getting isdnlog calls_merge state.\n");
+  /* cid_calls_merge_max_entry */
+  entry = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(widget),
+					    "cid_calls_merge_max_entry");
+  if (entry)
+    session->option_calls_merge_max_days =
+      strtol(gtk_entry_get_text(GTK_ENTRY(entry)), NULL, 0);
+  else
+    fprintf(stderr, "gtksettings_cb_ok: "
+	    "Error getting maximum number of days for isdnlog retrieval.\n");
+
   /* save checkbutton */
   button = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(widget),
 					     "save_checkbutton");
@@ -190,7 +233,7 @@ static void gtksettings_cb_ok(GtkWidget *window) {
   }
 }
 
-/* clicked "Save" at gtksettings_cb */
+/* clicked "Save" button at settings dialog (gtksettings_cb) */
 static void gtksettings_cb_save(GtkWidget *widget) {
   struct session_t *session = gtk_object_get_data(GTK_OBJECT(widget),
 						  "session");
@@ -198,6 +241,7 @@ static void gtksettings_cb_save(GtkWidget *widget) {
   settings_options_write(session);
 }
 
+/* clicked "Cancel" button at settings dialog (gtksettings_cb) */
 static void gtksettings_cb_cancel(GtkWidget *window) {
   struct session_t *session = gtk_object_get_data(GTK_OBJECT(window),
 						  "session");
@@ -205,6 +249,14 @@ static void gtksettings_cb_cancel(GtkWidget *window) {
     gtk_widget_destroy(window);
 }
 
+/*
+ * callback for setting widget sensitivity on toggle button change
+ */
+static void toggle_sensitive_register(GtkToggleButton *button,
+                                      GtkWidget *widget) {
+  gtk_widget_set_sensitive(widget, gtk_toggle_button_get_active(button));
+}
+
 /* Settings menu entry callback */
 void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   struct session_t *session = (struct session_t *) data;
@@ -216,9 +268,12 @@ void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   GtkWidget *frame;    /* the frames to separate msn/msns from sound devices */
   GtkWidget *notebook; /* to separate options into topics */
   GtkWidget *vbox; /* the vbox inside notebook with frames */
+  GtkWidget *vbox2; /* vbox inside frames */
 
   /* widgets to save (to evaluate later) */
   GtkWidget *save_checkbutton;           /* program page */
+  GtkWidget *popup_checkbutton;
+  GtkWidget *exec_on_incoming_entry; 
   GtkWidget *msn_entry;                  /* phone page */
   GtkWidget *msns_entry;
   GtkWidget *history_entry;
@@ -226,7 +281,10 @@ void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   GtkWidget *audio_device_name_in_entry; /* sound devices page */
   GtkWidget *audio_device_name_out_entry;
   GtkWidget *release_checkbutton; 
-  GtkWidget *exec_on_incoming_entry; 
+  GtkWidget *recformat_radiobutton; /* recording format */
+
+  GtkWidget *cid_calls_merge_checkbutton;
+  GtkWidget *cid_calls_merge_max_entry;
 
   char *s; /* temporary string */
 
@@ -251,7 +309,7 @@ void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show(frame);
 
-  table = gtk_table_new(2, 2, FALSE); /* rows, columns, not homogeneous */
+  table = gtk_table_new(3, 2, FALSE); /* rows, columns, not homogeneous */
   gtk_container_add(GTK_CONTAINER(frame), table);
   gtk_container_set_border_width(GTK_CONTAINER(table), 5);
   gtk_table_set_row_spacings(GTK_TABLE(table), 5);
@@ -264,17 +322,73 @@ void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   gtk_table_attach_defaults(GTK_TABLE(table), save_checkbutton, 0,2,0,1);
   gtk_widget_show(save_checkbutton);
 
+  popup_checkbutton =
+    gtk_check_button_new_with_label("Popup main window on incoming call");
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(popup_checkbutton),
+			       session->option_popup);
+  gtk_table_attach_defaults(GTK_TABLE(table), popup_checkbutton, 0,2,1,2);
+  gtk_widget_show(popup_checkbutton);
+
   label = gtk_label_new("Execute on incoming call:");
-  gtk_table_attach_defaults(GTK_TABLE(table), label, 0,1,1,2);
+  gtk_table_attach_defaults(GTK_TABLE(table), label, 0,1,2,3);
   gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
   gtk_widget_show(label);
 
   exec_on_incoming_entry = gtk_entry_new();
-  gtk_table_attach_defaults(GTK_TABLE(table), exec_on_incoming_entry, 1,2,1,2);
+  gtk_table_attach_defaults(GTK_TABLE(table), exec_on_incoming_entry, 1,2,2,3);
   gtk_entry_set_text(GTK_ENTRY(exec_on_incoming_entry),
 		     session->exec_on_incoming);
   gtk_widget_show(exec_on_incoming_entry);
 
+  frame = gtk_frame_new("Recording Format");
+  gtk_container_set_border_width(GTK_CONTAINER(frame), 10);
+  gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
+  gtk_widget_show(frame);
+
+  vbox2 = gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(frame), vbox2);
+  gtk_widget_show(vbox2);
+
+  recformat_radiobutton = gtk_radio_button_new_with_label(NULL,
+      "Microsoft WAV, uLaw");
+  gtk_box_pack_start(GTK_BOX(vbox2), recformat_radiobutton, FALSE, FALSE, 0);
+  gtk_widget_show(recformat_radiobutton);
+  gtk_object_set_data(GTK_OBJECT(recformat_radiobutton),
+      "rec_format", (gpointer) (RECORDING_FORMAT_WAV | RECORDING_FORMAT_ULAW));
+  if (session->option_recording_format == (enum recording_format_t)
+      gtk_object_get_data(GTK_OBJECT(recformat_radiobutton), "rec_format"))
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(recformat_radiobutton),TRUE);
+
+  recformat_radiobutton = gtk_radio_button_new_with_label_from_widget(
+      GTK_RADIO_BUTTON(recformat_radiobutton), "Microsoft WAV, 16-bit signed");
+  gtk_box_pack_start(GTK_BOX(vbox2), recformat_radiobutton, FALSE, FALSE, 0);
+  gtk_widget_show(recformat_radiobutton);
+  gtk_object_set_data(GTK_OBJECT(recformat_radiobutton),
+      "rec_format", (gpointer) (RECORDING_FORMAT_WAV | RECORDING_FORMAT_S16));
+  if (session->option_recording_format == (enum recording_format_t)
+      gtk_object_get_data(GTK_OBJECT(recformat_radiobutton), "rec_format"))
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(recformat_radiobutton),TRUE);
+
+  recformat_radiobutton = gtk_radio_button_new_with_label_from_widget(
+      GTK_RADIO_BUTTON(recformat_radiobutton), "Apple/SGI AIFF, uLaw");
+  gtk_box_pack_start(GTK_BOX(vbox2), recformat_radiobutton, FALSE, FALSE, 0);
+  gtk_widget_show(recformat_radiobutton);
+  gtk_object_set_data(GTK_OBJECT(recformat_radiobutton),
+      "rec_format", (gpointer) (RECORDING_FORMAT_AIFF | RECORDING_FORMAT_ULAW));
+  if (session->option_recording_format == (enum recording_format_t)
+      gtk_object_get_data(GTK_OBJECT(recformat_radiobutton), "rec_format"))
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(recformat_radiobutton),TRUE);
+
+  recformat_radiobutton = gtk_radio_button_new_with_label_from_widget(
+      GTK_RADIO_BUTTON(recformat_radiobutton), "Apple/SGI AIFF, 16-bit signed");
+  gtk_box_pack_start(GTK_BOX(vbox2), recformat_radiobutton, FALSE, FALSE, 0);
+  gtk_widget_show(recformat_radiobutton);
+  gtk_object_set_data(GTK_OBJECT(recformat_radiobutton),
+      "rec_format", (gpointer) (RECORDING_FORMAT_AIFF | RECORDING_FORMAT_S16));
+  if (session->option_recording_format == (enum recording_format_t)
+      gtk_object_get_data(GTK_OBJECT(recformat_radiobutton), "rec_format"))
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(recformat_radiobutton),TRUE);
+
   /* Phone page */
   vbox = gtk_vbox_new(FALSE, 0);
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox,
@@ -343,7 +457,7 @@ void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show(frame);
 
-  table = gtk_table_new(1, 2, FALSE); /* rows, columns, not homogeneous */
+  table = gtk_table_new(3, 2, FALSE); /* rows, columns, not homogeneous */
   gtk_container_add(GTK_CONTAINER(frame), table);
   gtk_container_set_border_width(GTK_CONTAINER(table), 5);
   gtk_table_set_row_spacings(GTK_TABLE(table), 5);
@@ -366,6 +480,39 @@ void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   free(s);
   gtk_widget_show(cid_max_entry);
 
+  cid_calls_merge_checkbutton = gtk_check_button_new_with_label(
+                                    "Read isdnlog data on startup");
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cid_calls_merge_checkbutton),
+			       session->option_calls_merge);
+  gtk_table_attach_defaults(GTK_TABLE(table), cid_calls_merge_checkbutton,
+                            0,2,1,2);
+  gtk_widget_show(cid_calls_merge_checkbutton);
+  
+  label = gtk_label_new("Maximum days to read from isdnlog:");
+  gtk_table_attach_defaults(GTK_TABLE(table), label, 0,1,2,3);
+  gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
+  gtk_widget_set_sensitive(label, session->option_calls_merge);
+  gtk_signal_connect(GTK_OBJECT(cid_calls_merge_checkbutton), "toggled",
+                     GTK_SIGNAL_FUNC(toggle_sensitive_register), label);
+  gtk_widget_show(label);
+
+  cid_calls_merge_max_entry = gtk_entry_new();
+  gtk_table_attach_defaults(GTK_TABLE(table), cid_calls_merge_max_entry,
+                            1,2,2,3);
+  if (session->option_calls_merge_max_days == 0) {
+    s = strdup("[no limit]");
+  } else {
+    asprintf(&s, "%u", session->option_calls_merge_max_days);
+  }
+  gtk_entry_set_text(GTK_ENTRY(cid_calls_merge_max_entry), s);
+  free(s);
+  gtk_widget_set_sensitive(cid_calls_merge_max_entry,
+                           session->option_calls_merge);
+  gtk_signal_connect(GTK_OBJECT(cid_calls_merge_checkbutton), "toggled",
+                     GTK_SIGNAL_FUNC(toggle_sensitive_register),
+		     cid_calls_merge_max_entry);
+  gtk_widget_show(cid_calls_merge_max_entry);
+
   /* Sound devices page */
   vbox = gtk_vbox_new(FALSE, 0);
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox,
@@ -428,15 +575,24 @@ void gtksettings_cb(GtkWidget *widget _U_, gpointer data, guint action _U_) {
 
   gtk_object_set_data(GTK_OBJECT(window), "save_checkbutton",
 		      (gpointer) save_checkbutton);
+  gtk_object_set_data(GTK_OBJECT(window), "popup_checkbutton",
+		      (gpointer) popup_checkbutton);
   gtk_object_set_data(GTK_OBJECT(window), "exec_on_incoming_entry",
 		      (gpointer) exec_on_incoming_entry);
 
+  gtk_object_set_data(GTK_OBJECT(window), "recording_format",
+    (gpointer) gtk_radio_button_group(GTK_RADIO_BUTTON(recformat_radiobutton)));
+    
   gtk_object_set_data(GTK_OBJECT(window), "msn_entry", (gpointer) msn_entry);
   gtk_object_set_data(GTK_OBJECT(window), "msns_entry", (gpointer) msns_entry);
   gtk_object_set_data(GTK_OBJECT(window), "history_entry",
 		      (gpointer) history_entry);
   gtk_object_set_data(GTK_OBJECT(window), "cid_max_entry",
 		      (gpointer) cid_max_entry);
+  gtk_object_set_data(GTK_OBJECT(window), "cid_calls_merge_checkbutton",
+		      (gpointer) cid_calls_merge_checkbutton);
+  gtk_object_set_data(GTK_OBJECT(window), "cid_calls_merge_max_entry",
+		      (gpointer) cid_calls_merge_max_entry);
 
   gtk_object_set_data(GTK_OBJECT(window), "audio_device_name_in_entry",
 		      (gpointer) audio_device_name_in_entry);
