@@ -3,19 +3,23 @@
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
- * Copyright 2002 Roland Stigge
+ * Copyright 2002, 2003 Roland Stigge
  *
  */
 
 #include "session.h"
 
+/* mediation internal recording buffer (number of shorts): */
+#define MEDIATION_RECBUFSIZE 16384
+
 extern int finished;
 extern int hangup;
 
 int mediation_makeLUT(int format_in, unsigned char **LUT_in,
 		      int format_out, unsigned char **LUT_out,
 		      unsigned char **LUT_generate,
-		      unsigned char **LUT_analyze);
+		      unsigned char **LUT_analyze,
+		      short **LUT_ulaw2short);
 int write_buf(int fd, unsigned char *outbuf, int outbuf_size);
 void process_isdn_source(struct session_t *session);
 void process_audio_source(struct session_t *session);
