@@ -1,10 +1,10 @@
 /*
  * server functionality:
- *   * let other processes issue commands (dial)
+ *   * let other processes issue commands (e.g. dial)
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
- * Copyright 2002 Roland Stigge
+ * Copyright 2002, 2003 Roland Stigge
  *
  */
 
@@ -68,6 +68,9 @@ int server_init(struct session_t *session) {
   /* bind (file) name to socket */
   if (bind(local_sock, (struct sockaddr *) &local_name, size)) {
     perror("local bind");
+    fprintf(stderr,
+	    "This program was possibly killed by accident on last run.\n"
+	    "In this case, try running it with option -r.\n");
     return -1;
   }
 
