@@ -3,7 +3,7 @@
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
- * Copyright 2002 Roland Stigge
+ * Copyright 2002, 2003 Roland Stigge
  *
  */
 
@@ -21,6 +21,9 @@
 #include <math.h>
 #include <time.h>
 
+/* GTK */
+#include <gtk/gtk.h>
+
 /* own header files */
 #include "session.h"
 #include "sound.h"
@@ -132,7 +135,8 @@ int session_audio_init(struct session_t *session) {
   if (mediation_makeLUT(session->audio_format_out, &session->audio_LUT_in,
 			session->audio_format_in, &session->audio_LUT_out,
 			&session->audio_LUT_generate,
-			&session->audio_LUT_analyze)) {
+			&session->audio_LUT_analyze,
+			&session->audio_LUT_ulaw2short)) {
     fprintf(stderr, "Error building conversion look-up-table.\n");
     return -1;
   }
@@ -143,8 +147,14 @@ int session_audio_init(struct session_t *session) {
     sample_size_from_format(session->audio_format_out);
 
   /* allocate buffers */
-  session->audio_inbuf  = (unsigned char *)malloc(session->fragment_size_in);
-  session->audio_outbuf = (unsigned char *)malloc(session->fragment_size_out);
+  if (!(session->audio_inbuf =
+      (unsigned char *)malloc(session->fragment_size_in))) {
+    return -1;
+  }
+  if (!(session->audio_outbuf =
+      (unsigned char *)malloc(session->fragment_size_out))) {
+    return -1;
+  }
 
   return 0;
 }
@@ -174,8 +184,14 @@ int session_isdn_init(struct session_t *session) {
   session->isdn_inbuf_size = session->isdn_outbuf_size = DEFAULT_ISDNBUF_SIZE;
 
   /* allocate buffers */
-  session->isdn_inbuf   = (unsigned char *)malloc(session->isdn_inbuf_size);
-  session->isdn_outbuf  = (unsigned char *)malloc(session->isdn_outbuf_size);
+  if (!(session->isdn_inbuf =
+      (unsigned char *)malloc(session->isdn_inbuf_size))) {
+    return -1;
+  }
+  if (!(session->isdn_outbuf =
+      (unsigned char *)malloc(session->isdn_outbuf_size))) {
+    return -1;
+  }
   
   if (isdn_setMSN(session->isdn_fd, session->msn) ||
       isdn_setMSNs(session->isdn_fd, session->msns)) {
@@ -189,6 +205,42 @@ int session_isdn_init(struct session_t *session) {
   return 0;
 }
 
+/*
+ * init recording related things in session
+ */
+int session_recording_init(struct session_t *session) {
+  /* mediation recording stuff */
+  session->rec_buf_local_size = MEDIATION_RECBUFSIZE;
+  session->rec_buf_remote_size = MEDIATION_RECBUFSIZE;
+  session->rec_buf_local_index = 0;
+  session->rec_buf_remote_index = 0;
+  if (!(session->rec_buf_local =
+    (short *) malloc(session->rec_buf_local_size * sizeof(short)))) {
+    return -1;
+  }
+  if (!(session->rec_buf_remote =
+    (short *) malloc(session->rec_buf_remote_size * sizeof(short)))) {
+    return -1;
+  }
+
+  if (!(session->recorder =
+	(struct recorder_t *)malloc(sizeof(struct recorder_t)))) {
+    return -1;
+  }
+
+  return 0;
+}
+
+/*
+ * deinit recording related things in session
+ */
+int session_recording_deinit(struct session_t *session) {
+  free(session->rec_buf_local);
+  free(session->rec_buf_remote);
+  free(session->recorder);
+  return 0;
+}
+
 /*
  * de-allocates memory used by audio buffers of session
  * -> prepares de-initialization
@@ -202,6 +254,7 @@ void session_audio_free(struct session_t *session) {
   free(session->audio_LUT_out);
   free(session->audio_LUT_generate);
   free(session->audio_LUT_analyze);
+  free(session->audio_LUT_ulaw2short);
 }
 
 /*
@@ -269,27 +322,42 @@ int session_init(struct session_t *session,
 		 char *audio_device_name_in,
 		 char *audio_device_name_out,
 		 char *msn, char *msns) {
-
+  int i;
+  
   /*
    * first: set all defaults possibly overridden by options file
-   */
+  */
 
   session->dial_number_history = NULL;
   session->dial_number_history = g_list_append(session->dial_number_history,
   					       strdup(""));
   session->dial_number_history_maxlen = 10; /* config overrides this */
-  session->cid_num_max = 0; /* 0 means no limit */
+  session->cid_num_max = 100; /* 0 means no limit */
 
-  /* defaults */
+  /* options defaults */
   session->option_save_options = 1; /* save options automatically (on exit) */
   session->option_release_devices = 1;
   session->option_show_llcheck = 1;
   session->option_show_callerid = 1;
   session->option_show_controlpad = 1;
   session->option_muted = 0;
+  session->option_record = 0;
+  session->option_record_local = 1;
+  session->option_record_remote = 1;
+  session->option_recording_format =
+    RECORDING_FORMAT_WAV | RECORDING_FORMAT_ULAW;
+  session->option_popup = 1;
+
+  session->option_calls_merge = 1;
+  session->option_calls_merge_max_days = 10;
 
   session->exec_on_incoming = strdup("");
 
+  for (i = 0; i < 4; i++) {
+    asprintf(&session->preset_names[i], "Preset %d", i + 1);
+    session->preset_numbers[i] = strdup("");
+  }
+
   session->audio_device_name_in = strdup(audio_device_name_in);
   session->audio_device_name_out = strdup(audio_device_name_out);
   session->msn = strdup(msn);
@@ -322,10 +390,14 @@ int session_init(struct session_t *session,
   session->touchtone_countdown_audio = 0;
   session->touchtone_index = 0;
 
+  session->ring_time = 0;
+  session->unanswered = 0;
+
   /* setup audio and isdn */
   if (!session->option_release_devices)
     if (session_audio_init(session) < 0) return -1;
   if (session_isdn_init(session) < 0) return -1;
+  if (session_recording_init(session) < 0) return -1;
 
   session->state = STATE_READY; /* initial state */
 
@@ -368,6 +440,8 @@ int session_deinit(struct session_t *session) {
   if (!session->option_release_devices)
     if (session_audio_deinit(session) < 0) return -1;
 
+  if (session_recording_deinit(session) < 0) return -1;
+  
   free(session->exec_on_incoming);
 
   /* clean up pre-set options */
@@ -540,6 +614,16 @@ void session_init_conversation(struct session_t *session) {
  * return: self_hangup: 1 == we hangup, 0 == other side hung up
  */
 void session_deinit_conversation(struct session_t *session, int self_hangup) {
+  if (session->option_record) {
+    recording_write(session->recorder, session->rec_buf_local,
+                    session->rec_buf_local_index, RECORDING_LOCAL);
+    recording_write(session->recorder, session->rec_buf_remote,
+                    session->rec_buf_remote_index, RECORDING_REMOTE);
+    recording_close(session->recorder);
+  }
+  session->rec_buf_local_index = 0;
+  session->rec_buf_remote_index = 0;
+  
   session_io_handlers_stop(session);
   session_reset_audio(session);
   session_io_handlers_start(session);
@@ -567,18 +651,36 @@ void session_deinit_conversation(struct session_t *session, int self_hangup) {
  * includes state transition
  */
 void session_start_conversation(struct session_t *session) {
+  char *digits; /* time in digits form */
+  
   if (isdn_set_full_duplex(session->isdn_fd)) {
     /* ISDN full duplex (REC start command) error */
     fprintf(stderr, "Error setting full duplex audio mode.\n");
     isdn_hangup(session->isdn_fd);
     session_set_state(session, STATE_READY);
-    cid_call_finished(session, "(HW ERROR)");
+    cid_set_duration(session, "(HW ERROR)");
   } else { /* full duplex ok: audio mode */
+    session->vcon_time = time(NULL); /* for caller id monitor */
+    cid_set_date(session, session->vcon_time);
     session_set_state(session, STATE_CONVERSATION);
+    if (session->option_record) {
+      if ((digits = util_digitstime(&session->vcon_time))) {
+        if (recording_open(session->recorder, digits,
+	                   session->option_recording_format)) {
+          fprintf(stderr, "Error opening audio file.\n");
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+				       session->record_checkbutton), FALSE);
+	}
+	free(digits);
+      } else {
+	fprintf(stderr, "Error generating audio filename.\n");
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
+	                             session->record_checkbutton), FALSE);
+      }
+    }
     if (isdn_blockmode(session->isdn_fd, 1)) /* blockmode error */
       fprintf(stderr,
 	      "Warning: Switching to ISDN blockmode not successful.\n");
-    session->vcon_time = time(NULL); /* for caller id monitor */
     session_init_conversation(session); /* init some conversation variables */
     
     session_io_handlers_stop(session);
@@ -700,11 +802,26 @@ int session_set_state(struct session_t *session, enum state_t state) {
     if (debug) fprintf(stderr, "New state: STATE_DIALING\n");
     break;
   case STATE_RINGING:
+    if (session->option_popup) {
+/* XXX: macros yet to define */
+#ifdef HAVE_GTK_WINDOW_PRESENT
+      gtk_window_present(GTK_WINDOW(session->main_window));
+#else
+      gdk_window_raise(session->main_window->window);
+#endif
+    }
     if (session->effect == EFFECT_NONE)
       session_effect_start(session, EFFECT_RING);
     if (debug) fprintf(stderr, "New state: STATE_RINGING\n");
     break;
   case STATE_RINGING_QUIET:
+    if (session->option_popup) {
+#ifdef HAVE_GTK_WINDOW_PRESENT
+      gtk_window_present(GTK_WINDOW(session->main_window));
+#else
+      gdk_window_raise(session->main_window->window);
+#endif
+    }
     if (debug) fprintf(stderr, "New state: STATE_RINGING_QUIET\n");
     break;
   case STATE_READY:
@@ -779,6 +896,7 @@ void gdk_handle_isdn_input(gpointer data, gint fd _U_,
       if (!strncmp(session->isdn_inbuf, "RING/", 5)) { /* -> RINGING state */
 	session->isdn_inbuf[session->isdn_inbuf_len - 2] = 0;
 	/* caller id update */
+	session->ring_time = time(NULL);
 	cid_add_line(session, CALL_IN, NULL, &session->isdn_inbuf[5]);
 
 	/* execute command if given */
@@ -800,13 +918,13 @@ void gdk_handle_isdn_input(gpointer data, gint fd _U_,
     if (isdn_try_read_line(session)){ /* a response to our dial request */
       if (strstr(session->isdn_inbuf, "BUSY\r\n")) { /* get back to READY  */
 	session_set_state(session, STATE_READY);
-	cid_call_finished(session, "(BUSY)");
+	cid_set_duration(session, "(BUSY)");
       } else if (strstr(session->isdn_inbuf, "VCON\r\n")) { /* let's go! */
 	session_start_conversation(session); /* including state transition */
       } else if (strstr(session->isdn_inbuf, "NO CARRIER\r\n")) {
 	/* timeout? */
 	session_set_state(session, STATE_READY);
-	cid_call_finished(session, "(TIMEOUT)");
+	cid_set_duration(session, "(TIMEOUT)");
       } else { /* got some other modem answer string while dialing out */
       }
     }
@@ -821,11 +939,12 @@ void gdk_handle_isdn_input(gpointer data, gint fd _U_,
 	/* got Caller ID */
 	session->isdn_inbuf[session->isdn_inbuf_len - 2] = 0;
 	/* complete from field */
-	cid_add_data(session, &session->isdn_inbuf[15]);
+	cid_set_from(session, &session->isdn_inbuf[15]);
       } else if (strstr(session->isdn_inbuf, "RUNG\r\n")) {
 	/* caller giving up */
 	session_set_state(session, STATE_READY);
-	cid_call_finished(session, "(RUNG)");
+	cid_set_duration(session, "(RUNG)");
+	cid_mark_row(session, session->cid_num - 1, 1);
       } else { /* got some other modem answer string while it rings */
       }
     }
@@ -844,7 +963,7 @@ void gdk_handle_isdn_input(gpointer data, gint fd _U_,
 	session_deinit_conversation(session, 1); /* 1 == let's hang up (I/O error) */
       
       session_set_state(session, STATE_READY);
-      cid_call_finished(session, NULL);
+      cid_set_duration(session, NULL);
     }
     break;
   case STATE_SERVICE:
@@ -917,7 +1036,7 @@ void gdk_handle_audio_input(gpointer data, gint fd _U_,
         /* 1 == let's hang up (I/O error) */
       
       session_set_state(session, STATE_READY);
-      cid_call_finished(session, NULL);
+      cid_set_duration(session, NULL);
     }
     break;
   case STATE_SERVICE:
@@ -982,6 +1101,7 @@ void gtk_handle_pick_up_button(GtkWidget *widget _U_, gpointer data) {
 	  session_history_add(session, number);
 	  
 	  /* caller id update */
+	  session->ring_time = time(NULL);
 	  cid_add_line(session, CALL_OUT, session->msn, clear_number);
 	}
       } else {
@@ -1035,7 +1155,7 @@ void gtk_handle_hang_up_button(GtkWidget *widget _U_, gpointer data) {
     if (tty_write(session->isdn_fd, "ATH\n"))
       fprintf(stderr, "Error answering call.\n");
     session_set_state(session, STATE_READY);
-    cid_call_finished(session, "(ABORTED)");
+    cid_set_duration(session, "(ABORTED)");
     break;
   case STATE_RINGING: /* reject call */
   case STATE_RINGING_QUIET: /* reject call */
@@ -1043,13 +1163,13 @@ void gtk_handle_hang_up_button(GtkWidget *widget _U_, gpointer data) {
     if (tty_write(session->isdn_fd, "ATH\n"))
       fprintf(stderr, "Error answering call.\n");
     session_set_state(session, STATE_READY);
-    cid_call_finished(session, "(REJECTED)");
+    cid_set_duration(session, "(REJECTED)");
     break;
   case STATE_CONVERSATION: /* hang up (while b-channel is open) */
     session_deinit_conversation(session, 1); /* 1 == we hang up ourselves ;) */
       
     session_set_state(session, STATE_READY);
-    cid_call_finished(session, NULL);
+    cid_set_duration(session, NULL);
     break;
   case STATE_SERVICE:
     break;
