@@ -3,7 +3,7 @@
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
- * Copyright 2002 Roland Stigge
+ * Copyright 2002, 2003 Roland Stigge
  *
  */
 
@@ -190,7 +190,7 @@ char *get_homedir() {
  * (used by options and history write functions)
  * returns 0 on success, -1 otherwise
  */
-static int touch_dir(char *dirname) {
+int touch_dir(char *dirname) {
 
   if (!mkdir(dirname, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH))
     return 0;
@@ -251,3 +251,25 @@ int substitute(char **s, char *x, char *y) {
  
   return result;
 }
+
+/*
+ * returns the date in the form of only digits, e.g. YYYYMMDDhhmmss
+ * the resulting string is dynamically allocated and should be deallocated
+ * with free().
+ *
+ * returns NULL on error
+ */
+char *util_digitstime(time_t *time) {
+  char *s = (char *)malloc(15);
+  int len;
+  
+  s[0] = '\1';
+  len = strftime(s, 15, "%Y%m%d%H%M%S", localtime(time));
+
+  if (len == 0 && s[0] != '\0') {
+    return NULL;
+  } else {
+    return s;
+  }
+}
+
