@@ -3,7 +3,7 @@
  *
  * This file is part of ANT (Ant is Not a Telephone)
  *
- * Copyright 2002 Roland Stigge
+ * Copyright 2002, 2003 Roland Stigge
  *
  */
 
@@ -32,7 +32,9 @@ char *timediff_str(time_t time1, time_t time0);
 char *ltostr(long int i);
 void execute(char *command);
 char *get_homedir();
+int touch_dir(char *dirname);
 int touch_dotdir();
 int substitute(char **s, char *x, char *y);
+char *util_digitstime(time_t *time);
 
 #endif /* util.h */
